summaryrefslogtreecommitdiff
path: root/framework/source/services/desktop.cxx
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
committerThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
commit60fbefc615f8931bf8b952293fc4eb4ac35dafd8 (patch)
tree2a91fcbcb206d60dcc652a336bb9b6813578815e /framework/source/services/desktop.cxx
parent7f71ed1c62775a4e5b2efebf55f284a5c32b2df4 (diff)
fdo#60724 informations -> information
Change-Id: Ifd34ebfc7fe01b4a470eb072597dd3ec97c97863
Diffstat (limited to 'framework/source/services/desktop.cxx')
-rw-r--r--framework/source/services/desktop.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index b46b5c8fff3f..6e8edbea9b2c 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -129,7 +129,7 @@ DEFINE_INIT_SERVICE ( Desktop,
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
//-------------------------------------------------------------------------------------------------------------
@@ -208,7 +208,7 @@ Desktop::Desktop( const css::uno::Reference< css::lang::XMultiServiceFactory >&
, ::cppu::OWeakObject ( )
// Init member
#ifdef ENABLE_ASSERTIONS
- , m_bIsTerminated ( sal_False ) // see dispose() for further informations!
+ , m_bIsTerminated ( sal_False ) // see dispose() for further information!
#endif
, m_xFactory ( xFactory )
, m_aChildTaskContainer ( )
@@ -358,7 +358,7 @@ sal_Bool SAL_CALL Desktop::terminate()
{
#ifdef ENABLE_ASSERTIONS
// "Protect" us against dispose before terminate calls!
// see dispose() for further informations.
/* SAFE AREA --------------------------------------------------------------------------------------- */
WriteGuard aWriteLock( m_aLock );
m_bIsTerminated = sal_True;
@@ -1234,7 +1234,7 @@ void SAL_CALL Desktop::dispose()
/*-************************************************************************************************************//**
@interface XComponent
@short add/remove listener for dispose events
- @descr Add an event listener to this object, if you whish to get informations
+ @descr Add an event listener to this object, if you whish to get information
about our dieing!
You must releas ethis listener reference during your own disposing() method.
@@ -1283,7 +1283,7 @@ void SAL_CALL Desktop::removeEventListener( const css::uno::Reference< css::lang
@seealso method loadComponentFromURL()
- @param "aEvent", state event which (hopefully) valid informations
+ @param "aEvent", state event which (hopefully) valid information
@return -
@onerror -
@@ -1618,7 +1618,7 @@ void SAL_CALL Desktop::getFastPropertyValue( css::uno::Any& aValue ,
@seealso class OPropertySetHelper
@param -
- @return structure with property-informations
+ @return structure with property-information
@onerror -
@threadsafe yes
@@ -358,7 +358,7 @@ sal_Bool SAL_CALL Desktop::terminate()
#ifdef ENABLE_ASSERTIONS
// "Protect" us against dispose before terminate calls!
- // see dispose() for further informations.
+ // see dispose() for further information.
/* SAFE AREA --------------------------------------------------------------------------------------- */
WriteGuard aWriteLock( m_aLock );